# FAQ: Contributing

## How can I contribute?

We welcome any and all kinds of contribution, including:

 * bug fixes and code contributions
 * ideas for new features
 * testing
 * documentation improvements
 * stlyistic improvements on the linkml site

You are free to make PRs on any LinkML repo, including:

 * [linkml](https://github.com/linkml/linkml)
 * [linkml-runtime](https://github.com/linkml/linkml-runtime)
 * [linkml-model](https://github.com/linkml/linkml-model)

For issues, we prefer you to use the main linkml repo

## How do I stay involved?

We have a slack channel for the core team and adopted of bleeding edge new features - just let us know via a GitHub issue if you would like an invite!

